==> zzyj-financeintegration-api-3.0.0-20230214.022239-62-sources.jar: com/ejianc/business/financeintegration/PMPayApply/vo/PMZZCRKDVO.java <==
package com.ejianc.business.financeintegration.PMPayApply.vo;

import java.io.Serializable;
import java.math.BigDecimal;

public class PMZZCRKDVO implements Serializable {

    private static final long serialVersionUID = -6550871832456894273L;

    /**
     * 项目ID
     */
    private String projectId;

    /**
     * 合同ID
     */
    private String contractId;


    /**
     * 来源ID
     */
    private String sourceId;


    /**
     * 验收日期
     */
    private String checkDate;

    /**
     * 材料分类名称
     */
    private String materialTypeName;

    /**
     * 材料名称
     */
    private String materialName;

    /**
     * 材料Id
     */
    private String materialId;

    /**
     * 规格型号
     */
    private String spec;

    /**
     * 单位
     */
    private String unitName;

    /**
     * 数量
     */
    private BigDecimal checkNum;

    /**
     * 金额
     */
    private BigDecimal checkTaxMny;

    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }

    public String getContractId() {
        return contractId;
    }

    public void setContractId(String contractId) {
        this.contractId = contractId;
    }

    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }

    public String getCheckDate() {
        return checkDate;
    }

    public void setCheckDate(String checkDate) {
        this.checkDate = checkDate;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getMaterialId() {
        return materialId;
    }

    public void setMaterialId(String materialId) {
        this.materialId = materialId;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }

    public BigDecimal getCheckNum() {
        return checkNum;
    }

    public void setCheckNum(BigDecimal checkNum) {
        this.checkNum = checkNum;
    }

    public BigDecimal getCheckTaxMny() {
        return checkTaxMny;
    }

    public void setCheckTaxMny(BigDecimal checkTaxMny) {
        this.checkTaxMny = checkTaxMny;
    }
}

==> zzyj-financeintegration-api-3.0.0-20250912.043409-126-sources.jar: com/ejianc/business/financeintegration/PMPayApply/vo/PMZZCRKDVO.java <==
package com.ejianc.business.financeintegration.PMPayApply.vo;

import java.io.Serializable;
import java.math.BigDecimal;

public class PMZZCRKDVO implements Serializable {

    private static final long serialVersionUID = -6550871832456894273L;

    /**
     * 项目ID
     */
    private String projectId;

    /**
     * 合同ID
     */
    private String contractId;


    /**
     * 来源ID
     */
    private String sourceId;


    /**
     * 验收日期
     */
    private String checkDate;

    /**
     * 材料分类名称
     */
    private String materialTypeName;

    /**
     * 材料名称
     */
    private String materialName;

    /**
     * 材料Id
     */
    private String materialId;

    /**
     * 规格型号
     */
    private String spec;

    /**
     * 单位
     */
    private String unitName;

    /**
     * 数量
     */
    private BigDecimal checkNum;

    /**
     * 金额
     */
    private BigDecimal checkTaxMny;

    /**
     * 金额(不含税)
     */
    private BigDecimal checkMny;

    /**
     * 税额
     */
    private BigDecimal taxMny;

    public String getProjectId() {
        return projectId;
    }

    public BigDecimal getCheckMny() {
        return checkMny;
    }

    public void setCheckMny(BigDecimal checkMny) {
        this.checkMny = checkMny;
    }

    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }

    public String getContractId() {
        return contractId;
    }

    public void setContractId(String contractId) {
        this.contractId = contractId;
    }

    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }

    public String getCheckDate() {
        return checkDate;
    }

    public void setCheckDate(String checkDate) {
        this.checkDate = checkDate;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getMaterialId() {
        return materialId;
    }

    public void setMaterialId(String materialId) {
        this.materialId = materialId;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }

    public BigDecimal getCheckNum() {
        return checkNum;
    }

    public void setCheckNum(BigDecimal checkNum) {
        this.checkNum = checkNum;
    }

    public BigDecimal getCheckTaxMny() {
        return checkTaxMny;
    }

    public void setCheckTaxMny(BigDecimal checkTaxMny) {
        this.checkTaxMny = checkTaxMny;
    }
}
